@@ -12,5 +12,17 @@ impl std::fmt::Display for BitfieldSliceError {
         )
     }
 }
+impl std::error::Error for BitfieldSliceError {}
 
-impl std::error::Error for BitfieldSliceError {}
\ No newline at end of file
+#[derive(Debug)]
+pub struct BitfieldHexError(pub char, pub usize);
+
+impl std::fmt::Display for BitfieldHexError {
+    fn fmt(&self, fmt: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        write!(
+            fmt,
+            "found Invalid character {} @ index {}.",
+            self.0, self.1
+        )
+    }
+}
\ No newline at end of file
